<?php
/**
* Plugin Name:     Easy Digital Downloads - All Access
* Plugin URI:      http://easydigitaldownloads.com/downloads/all-access/
* Description:     Sell "All Access" memberships to your customers so they can download any product.
* Version:         1.0.9
* Author:          Phil Johnston
* Author URI:      https://mintplugins.com
* Text Domain:     edd_all_access
*
* @package         EDD\EddAllAccess
* @author          Phil Johnston
* @copyright       Copyright (c) Easy Digital Downloads
*/


// Exit if accessed directly
if( !defined( 'ABSPATH' ) ) {
	exit;
}

// Plugin version
define( 'EDD_ALL_ACCESS_VER', '1.0.9' );

// Plugin path
define( 'EDD_ALL_ACCESS_DIR', plugin_dir_path( __FILE__ ) );

// Plugin URL
define( 'EDD_ALL_ACCESS_URL', plugin_dir_url( __FILE__ ) );

// Plugin Root File
define( 'EDD_ALL_ACCESS_FILE', __FILE__ );

if( !class_exists( 'EDD_All_Access' ) ) {

  /**
  * Main EDD_All_Access class
  *
  * @since       1.0.0
  */
  class EDD_All_Access {

	/**
	* @var         EDD_All_Access $instance The one true EDD_All_Access
	* @since       1.0.0
	*/
	private static $instance;

	/**
	* @var EDD_All_Access_Recurring
	*/
	public static $edd_recurring;

	/**
	* @var EDD_All_Access_Software_Licensing
	*/
	public static $edd_software_licensing;

	/**
	* @var EDD_All_Access_Content_Restriction
	*/
	public static $edd_content_restriction;

	/**
	* @var EDD_All_Access_Commissions
	*/
	public static $edd_commissions;

	/**
	* @var EDD_All_Access_Bookings
	*/
	public static $edd_bookings;

	/**
	* @var EDD_All_Access_Downloads_As_Services
	*/
	public static $edd_downloads_as_services;

	/**
	* @var EDD_All_Access_Simple_Shipping
	*/
	public static $edd_simple_shipping;

	/**
	* @var EDD_All_Access_Fes
	*/
	public static $edd_fes;

	/**
	* @var EDD_All_Access_Free_Downloads
	*/
	public static $edd_free_downloads;

	/**
	* @var EDD_All_Access_Custom_Prices
	*/
	public static $edd_custom_prices;

	/**
	* @var EDD_All_Access_Auto_register
	*/
	public static $edd_auto_register;

	/**
	* @var EDD_All_Access_Marketify
	*/
	public static $marketify_theme;

	/**
	* @var EDD_All_Access_Restrict_Content_Pro
	*/
	public static $restrict_content_pro;

	/**
	* Get active instance
	*
	* @access      public
	* @since       1.0.0
	* @return      object self::$instance The one true EDD_All_Access
	*/
	public static function instance() {
	  if( !self::$instance ) {
		self::$instance = new EDD_All_Access();
		self::$instance->includes();
		self::$instance->load_textdomain();
		self::$instance->hooks();

		// Set up integrated plugins
		self::$edd_recurring = new EDD_All_Access_Recurring();
		self::$edd_software_licensing = new EDD_All_Access_Software_Licensing();
		self::$edd_content_restriction = new EDD_All_Access_Content_Restriction();
		self::$edd_commissions = new EDD_All_Access_Commissions();
		self::$edd_bookings = new EDD_All_Access_Bookings();
		self::$edd_downloads_as_services = new EDD_All_Access_Downloads_As_Services();
		self::$edd_simple_shipping = new EDD_All_Access_Simple_Shipping();
		self::$edd_fes = new EDD_All_Access_Fes();
		self::$edd_free_downloads = new EDD_All_Access_Free_Downloads();
		self::$edd_custom_prices = new EDD_All_Access_Custom_Prices();
		self::$edd_auto_register = new EDD_All_Access_Auto_Register();
		self::$restrict_content_pro = new EDD_All_Access_Restrict_Content_Pro();

		// Set up integrated themes:
		self::$marketify_theme = new EDD_All_Access_Marketify();

	  }

	  return self::$instance;
	}

	/**
	* Include necessary files
	*
	* @access      private
	* @since       1.0.0
	* @return      void
	*/
	private function includes() {

	  // Include scripts
	  require_once EDD_ALL_ACCESS_DIR . 'includes/functions/enqueue-scripts.php';

	  // Include misc functions
	  require_once EDD_ALL_ACCESS_DIR . 'includes/functions/misc-functions.php';

	  // Upgrade Functions
	  require_once EDD_ALL_ACCESS_DIR . 'includes/functions/upgrades.php';

	  // Include receipt functions
	  require_once EDD_ALL_ACCESS_DIR . 'includes/functions/receipts.php';

	  // Include All Access status functions
	  require_once EDD_ALL_ACCESS_DIR . 'includes/functions/all-access-status-functions.php';

	  // Include Downloading functions
	  require_once EDD_ALL_ACCESS_DIR . 'includes/functions/downloading-functions.php';

	  // Include Download Form functions
	  require_once EDD_ALL_ACCESS_DIR . 'includes/functions/download-form.php';

	  // Include helper functions
	  require_once EDD_ALL_ACCESS_DIR . 'includes/functions/helper-functions.php';

	  // Include ajax callback functions
	  require_once EDD_ALL_ACCESS_DIR . 'includes/functions/ajax-callbacks.php';

	  // Include Customer Meta functions
	  require_once EDD_ALL_ACCESS_DIR . 'includes/admin/customers/customers.php';

	  // Include All Access Single View page
	  require_once EDD_ALL_ACCESS_DIR . 'includes/admin/custom-pages/all-access-passes-page.php';

	  // Include site-wide settings under downloads > settings > all-access
	  require_once EDD_ALL_ACCESS_DIR . 'includes/admin/settings/settings.php';

	  // Include Post Meta options
	  require_once EDD_ALL_ACCESS_DIR . 'includes/admin/post-meta/all-access-metabox.php';
	  require_once EDD_ALL_ACCESS_DIR . 'includes/admin/post-meta/prices-metabox.php';

	  // Include Shortcodes
	  require_once EDD_ALL_ACCESS_DIR . 'includes/functions/shortcodes.php';

	  // EDD_All_Access_Pass object
	  require_once EDD_ALL_ACCESS_DIR . 'includes/functions/class-edd-all-access-pass.php';

	  // Tools added to EDD > Tools page
	  require_once EDD_ALL_ACCESS_DIR . 'includes/functions/tools.php';

	  // Discount Code functions
	  require_once EDD_ALL_ACCESS_DIR . 'includes/admin/discount-codes/discount-codes.php';

	  // Integration functions to make this work with EDD Recurring
	  require_once EDD_ALL_ACCESS_DIR . 'includes/integrations/plugin-recurring.php';

	  // Integration with EDD Software Licensing
	  require_once EDD_ALL_ACCESS_DIR . 'includes/integrations/plugin-software-licenses.php';

	  // Integration with EDD Content Restriction
	  require_once EDD_ALL_ACCESS_DIR . 'includes/integrations/plugin-content-restriction.php';

	  // Integration with EDD Commissions
	  require_once EDD_ALL_ACCESS_DIR . 'includes/integrations/plugin-commissions.php';

	  // Integration with EDD Bookings
	  require_once EDD_ALL_ACCESS_DIR . 'includes/integrations/plugin-bookings.php';

	  // Integration with EDD Downloads as Services
	  require_once EDD_ALL_ACCESS_DIR . 'includes/integrations/plugin-downloads-as-services.php';

	  // Integration with EDD Simple Shipping
	  require_once EDD_ALL_ACCESS_DIR . 'includes/integrations/plugin-simple-shipping.php';

	  // Integration with FES
	  require_once EDD_ALL_ACCESS_DIR . 'includes/integrations/plugin-fes.php';

	  // Integration with Free Downloads
	  require_once EDD_ALL_ACCESS_DIR . 'includes/integrations/plugin-free-downloads.php';

	  // Integration with Custom Prices
	  require_once EDD_ALL_ACCESS_DIR . 'includes/integrations/plugin-custom-prices.php';

	  // Integration with Auto Register
	  require_once EDD_ALL_ACCESS_DIR . 'includes/integrations/plugin-auto-register.php';

	  // Integration with Marketify Theme
	  require_once EDD_ALL_ACCESS_DIR . 'includes/integrations/theme-marketify.php';

	  // Integration with Restrict Content Pro
	  require_once EDD_ALL_ACCESS_DIR . 'includes/integrations/plugin-restrict-content-pro.php';

	}

	/**
	* Run action and filter hooks
	*
	* @access      private
	* @since       1.0.0
	* @return      void
	*
	*/
	private function hooks() {
	  // Handle licensing
	  if( class_exists( 'EDD_License' ) ) {
		$license = new EDD_License( __FILE__, 'All Access', EDD_ALL_ACCESS_VER, 'MintPlugins' );
	  }

	  // Register a dashboard page so we can view single All Access pass data
	  add_action( 'admin_menu', array( $this, 'all_access_passes_view_page' ), 10 );
	}

	/**
	 * Register our All Access single view page
	 *
	 * @since  1.0.0
	 * @return void
	 */
	public function all_access_passes_view_page() {
		add_submenu_page(
			NULL,
			'This page is not shown in any menu',
			'This page is not shown in any menu',
			'view_shop_reports',
			'edd-all-access-pass',
			'edd_all_access_pass_page'
		);
	}

	/**
	* Internationalization
	*
	* @access      public
	* @since       1.0.0
	* @return      void
	*/
	public function load_textdomain() {
	  // Set filter for language directory
	  $lang_dir = EDD_ALL_ACCESS_DIR . '/languages/';
	  $lang_dir = apply_filters( 'edd_all_access_languages_directory', $lang_dir );

	  // Traditional WordPress plugin locale filter
	  $locale = apply_filters( 'plugin_locale', get_locale(), 'edd-all-access' );
	  $mofile = sprintf( '%1$s-%2$s.mo', 'edd-all-access', $locale );

	  // Setup paths to current locale file
	  $mofile_local   = $lang_dir . $mofile;
	  $mofile_global  = WP_LANG_DIR . '/edd-all-access/' . $mofile;

	  if( file_exists( $mofile_global ) ) {
		// Look in global /wp-content/languages/edd_all_access/ folder
		load_textdomain( 'edd-all-access', $mofile_global );
	  } elseif( file_exists( $mofile_local ) ) {
		// Look in local /wp-content/plugins/edd_all_access/languages/ folder
		load_textdomain( 'edd-all-access', $mofile_local );
	  } else {
		// Load the default language files
		load_plugin_textdomain( 'edd-all-access', false, $lang_dir );
	  }
	}
  }
} // End if class_exists check

/**
* The main function responsible for returning the one true EDD_All_Access
* instance to functions everywhere
*
* @since       1.0.0
* @return      \EDD_All_Access The one true EDD_All_Access
*
* @todo        Inclusion of the activation code below isn't mandatory, but
*              can prevent any number of errors, including fatal errors, in
*              situations where your extension is activated but EDD is not
*              present.
*/
function edd_all_access() {

	if ( version_compare( phpversion(), '5.3', '<' ) ){
		echo __( 'You need to be running version 5.3 of PHP or later to use EDD All Access. Contact your webhost to have them upgrade your PHP version' );
	}
	if ( ! defined( 'EDD_VERSION' ) || version_compare( EDD_VERSION, '2.8', '<' ) ){
		add_action( 'admin_notices', 'edd_all_access_edd_too_old_notice' );
	}
	if( ! class_exists( 'Easy_Digital_Downloads' ) ) {
		if( ! class_exists( 'EDD_Extension_Activation' ) ) {
		  require_once 'includes/updates/class.extension-activation.php';
		}

		$activation = new EDD_Extension_Activation( plugin_dir_path( __FILE__ ), basename( __FILE__ ) );
		$activation = $activation->run();
	} else {
		return EDD_All_Access::instance();
	}
}
add_action( 'plugins_loaded', 'edd_all_access' );

/**
* Admin notice used if EDD is not updated to 2.8 or later.
*
* @since       1.0.0
*/
function edd_all_access_edd_too_old_notice(){
  ?>
  <div class="notice notice-error">
	<p><?php echo __( 'EDD All Access: Your version of Easy Digital Downloads must be updated to version 2.8 or later to use the All Access extension', 'edd-all-access' ); ?></p>
  </div>
  <?php
}

/**
* Upon fresh activation, this function fires and prevents all previous upgrade routines from running as they are not needed on fresh installs.
*
* @since       1.0.0
*/
function edd_all_access_install() {

	$current_version = get_option( 'edd_all_access_version' );

	if ( ! $current_version ) {

		if( defined( 'EDD_PLUGIN_DIR' ) ) {

			require_once EDD_PLUGIN_DIR . 'includes/admin/upgrades/upgrade-functions.php';

			// When new upgrade routines are added, mark them as complete on fresh install
			$upgrade_routines = array(
				'aa_v1_reorganize_customer_meta',
			);

			foreach ( $upgrade_routines as $upgrade ) {
				edd_set_upgrade_complete( $upgrade );
			}

		}

	}

	add_option( 'edd_all_access_version', EDD_ALL_ACCESS_VER, '', false );

}
register_activation_hook( __FILE__, 'edd_all_access_install' );
