<?php
/**
 * Functions that deal with outputting/saving the metabox called "All Access".
 *
 * @package     EDD\EDDAllAccess\Post Meta Functions
 * @since       1.0.0
 */


// Exit if accessed directly
if( !defined( 'ABSPATH' ) ) exit;

function edd_all_access_add_meta_box() {

	if( current_user_can( 'manage_shop_settings' ) ) {
		add_meta_box( 'edd_downloads_all_access', __( 'All Access', 'edd-all-access' ), 'edd_all_access_render_all_access_meta_box', 'download', 'normal', 'high' );
	}
}
add_action( 'add_meta_boxes', 'edd_all_access_add_meta_box', 100 );

// render the download information meta box
function edd_all_access_render_all_access_meta_box() {
	global $post;

	// Use nonce for verification
	echo '<input type="hidden" name="edd_download_all_access_meta_box_nonce" value="', wp_create_nonce( basename( __FILE__ ) ), '" />';

	echo '<table class="form-table">';

	// Main Options
	$enabled = get_post_meta( $post->ID, '_edd_all_access_enabled', true ) ? true : false;
	$meta    = get_post_meta( $post->ID, '_edd_all_access_settings', true );
	$all_access_duration_number = isset( $meta['all_access_duration_number'] ) ? $meta['all_access_duration_number'] : 1;
	$all_access_duration_unit = isset( $meta['all_access_duration_unit'] ) ? $meta['all_access_duration_unit'] : '';
	$download_limit  = isset( $meta['all_access_download_limit']  ) ? $meta['all_access_download_limit']  : 0;
	$download_limit_time_period  = isset( $meta['all_access_download_limit_time_period']  ) ? $meta['all_access_download_limit_time_period']  : '';
	$all_access_categories = isset( $meta['all_access_categories']  ) ? $meta['all_access_categories']  : array();
	$number_of_price_ids  = isset( $meta['all_access_number_of_price_ids']  ) ? $meta['all_access_number_of_price_ids']  : 0;
	$included_price_ids = isset( $meta['all_access_included_price_ids']  ) ? $meta['all_access_included_price_ids']  : array();

	// Receipt Options
	$receipt_meta = get_post_meta( $post->ID, '_edd_all_access_receipt_settings', true );

	$show_all_access_link_in_receipt = isset( $receipt_meta['show_link'] ) ? $receipt_meta['show_link'] : 'show_link';

	$edd_slug = ! defined( 'EDD_SLUG' ) ? 'downloads' : EDD_SLUG;

	$all_access_link_in_receipt_url = isset( $receipt_meta['link_url'] ) ? $receipt_meta['link_url'] : home_url() . '/' . $edd_slug . '/';
	$all_access_link_in_receipt_message = isset( $receipt_meta['link_message'] ) ? $receipt_meta['link_message'] : __( 'Click here to use your All Access Pass', 'edd-all-access' );

	$display = $enabled ? '' : ' style="display:none";';

	echo '<tr>';
		echo '<td class="edd_field_type_text" colspan="2">';
			echo '<p><strong>' . __( 'Convert this product into an "All Access" pass?', 'edd-all-access' ) . '</strong></p>';
			echo '<input type="checkbox" name="edd_all_access_enabled" id="edd_all_access_enabled" value="1" ' . esc_attr( checked( true, $enabled, false ) ) . '/>&nbsp;';
			echo '<label for="edd_all_access_enabled">' . __( 'If a customer buys this product, should they be given All Access?', 'edd-all-access' ) . ' <a href="http://docs.easydigitaldownloads.com/article/1757-all-access-overview" target="_blank">' . __( 'Learn More', 'edd-all-access' ) . '</label>';
		echo '<td>';
	echo '</tr>';

	//All Access Categories
	echo '<tr' . $display . ' class="edd_all_access_categories_row edd_all_access_row">';
		echo '<td class="edd_field_type_text" colspan="2">';
			echo '<p><strong>' . __( 'All Access To:', 'edd-all-access' );
			echo '<span alt="f223" class="edd-help-tip dashicons dashicons-editor-help" title="' . __( '<strong>Limit by category</strong>: You can choose which products customers can download with this All Access pass. For example, if you want to sell an All Access pass to just a category called Photos, choose that category here. Note that the category must already exist for it to show up here. You can make product categories under Downloads > Categories.', 'edd-all-access' ) . '"></span>';
			echo '</strong></p>';
			echo '<label for="edd_all_access_meta_all_access_categories">' . __( 'To which product categories does the customer get "All Access"', 'edd-all-access' ) .'</label><br />';

			$categories = get_terms( 'download_category', apply_filters( 'edd_category_dropdown', array() ) );
			$options    = array();

			foreach ( $categories as $category ) {
				$options[ absint( $category->term_id ) ] = esc_html( $category->name );
			}

			// Default to all categories included
			if( empty( $all_access_categories ) ){
				$all_access_categories['all'] = __( 'All Products', 'edd-all-access' );
			}

			echo EDD()->html->select( array(
				'options'          => $options,
				'name'             => 'edd_all_access_meta[all_access_categories][]',
				'selected'         => $all_access_categories,
				'id'               => 'edd_all_access_meta_all_access_categories',
				'class'            => 'edd_all_access_meta_all_access_categories',
				'chosen'           => true,
				'placeholder'      => __( 'Type to search Categories', 'edd-all-access' ),
				'multiple'         => true,
				'show_option_all'  => __( 'All Products', 'edd-all-access' ),
				'show_option_none' => false,
				'data'             => array( 'search-type' => 'no_ajax' )
			) );

		echo '<td>';
	echo '</tr>';

	// Length of All Access duration
	$all_access_duration_unit_options = array(
		'never' =>  __( 'Never Expires', 'edd-all-access' ),
		'year' => __( 'Year(s)', 'edd-all-access' ),
		'month' => __( 'Month(s)', 'edd-all-access' ),
		'week' => __( 'Week(s)', 'edd-all-access' ),
		'day' => __( 'Day(s)', 'edd-all-access' )
	);

	$all_access_duration_unit_options = apply_filters( 'edd_all_access_duration_unit_metabox_options', $all_access_duration_unit_options );

	echo '<tr' . $display . ' class="edd_all_access_row">';
		echo '<td class="edd_field_type_text" colspan="2">';
			echo '<p><strong>' . __( '"All Access" Duration:', 'edd-all-access' ) . '</strong>';
			echo '<span alt="f223" class="edd-help-tip dashicons dashicons-editor-help" title="' . __( '<strong>What is All Access duration?</strong>: You can set an expiration date for this All Access pass. Once a customer\'s All Access pass expires, they can no longer download products using that pass. If you want to make this renewable (like an ongoing membership), you will want to use the EDD Recurring extension so that this All Access pass is automatically repurchased by the customer once it expires.', 'edd-all-access' ) . '"></span>';
			echo '</p>';
			echo '<label for="edd_all_access_meta_all_access_duration_unit">' . __( 'How long should "All Access" last?', 'edd-all-access' ) . '</label><br />';

				// The field containing the number value
				 echo '<input style="display:none;" type="number" class="small-text" placeholder="1" id="edd_all_access_meta_all_access_duration_number" name="edd_all_access_meta[all_access_duration_number]" value="' . esc_attr( $all_access_duration_number ) . '" min="1" />';

				// The field containing the time unit value
				echo '<select name="edd_all_access_meta[all_access_duration_unit]" id="edd_all_access_meta_all_access_duration_unit">';

				  foreach( $all_access_duration_unit_options as $time_period_slug => $output_string ){
					  echo '<option value="' . esc_attr( $time_period_slug ) . '" ' . esc_attr( selected( $time_period_slug, $all_access_duration_unit, false ) ) . '>' . $output_string . '</option>';
				  }

				echo '</select>';

		echo '<td>';
	echo '</tr>';

	// Download Limit
	echo '<tr' . $display . ' class="edd_all_access_row">';
		echo '<td class="edd_field_type_text" colspan="2">';
			echo '<p><strong>' . __( 'Download Limit:', 'edd-all-access' ) . '</strong></p>';
			echo '<label for="edd_all_access_download_limit">' . __( 'How many downloads should the customer get? Leave blank or enter "0" for unlimited. Note: If a customer\'s account is expired, they won\'t be able to download - even if they have not hit this limit yet.', 'edd-all-access' ) . '</label><br />';
			echo '<input type="number" class="small-text" name="edd_all_access_meta[download_limit]" id="edd_all_access_download_limit" value="' . esc_attr( $download_limit ) . '" min="0" />&nbsp;';
			echo '<span id="edd_all_access_unlimited_download_limit_note" style="display:none;">' . __( '(Unlimited downloads per day)', 'edd-all-access' ) . '</span>';

			// Downloads allowed per All Access Period
			$download_limit_time_period_options = array(
				'per_day' => __( 'X downloads per day', 'edd-all-access' ),
				'per_week' => __( 'X downloads per week', 'edd-all-access' ),
				'per_month' => __( 'X downloads per month', 'edd-all-access' ),
				'per_year' => __( 'X downloads per year', 'edd-all-access' ),
				'per_period' => __( 'X downloads total', 'edd-all-access' )
			);

			$download_limit_time_period_options = apply_filters( 'edd_all_access_download_limit_options', $download_limit_time_period_options );


				echo '<select name="edd_all_access_meta[download_limit_time_period]" id="edd_all_access_meta_download_limit_time_period">';

				  foreach( $download_limit_time_period_options as $time_period_slug => $output_string ){
					  echo '<option value="' . esc_attr( $time_period_slug ) . '" ' . esc_attr( selected( $time_period_slug, $download_limit_time_period, false ) ) . '>' . $output_string . '</option>';
				  }

				echo '</select>';

		echo '<td>';
	echo '</tr>';

	//All Access Price Variations - How many?
	echo '<tr' . $display . ' class="edd_all_access_number_of_price_ids_row edd_all_access_row">';
		echo '<td class="edd_field_type_text" colspan="2">';
			echo '<p><strong>' . __( 'Total Price Variations (Optional):', 'edd-all-access' ) . '</strong></p>';
			echo '<label for="edd_all_access_meta_all_access_number_of_price_ids">' . __( 'How many price variations are there? Leave blank or enter "0" to include all price variations.', 'edd-all-access' ) . '</label><br />';
			echo '<input type="number" class="small-text" name="edd_all_access_meta[number_of_price_ids]" id="edd_all_access_number_of_price_ids" value="' . esc_attr( $number_of_price_ids ) . '" min="0" />&nbsp;';
			echo '<p id="edd_all_access_included_price_ids_note" style="display:none;">' . __( 'Because this is set to 0, all price variations are included.', 'edd-all-access' ) . '</p>';
		echo '<td>';
	echo '</tr>';

	//All Access Price Variations - Which are included?
	echo '<tr style="display:none;" class="edd_all_access_included_price_ids_row">';
		echo '<td class="edd_field_type_text" colspan="2">';
			echo '<p><strong>' . __( 'Included Price Variations:', 'edd-all-access' ) . '</strong></p>';
			echo '<label for="edd_all_access_included_price_ids">' . __( 'Which price variations should be included in this All Access?', 'edd-all-access' ) . '</label>';

			echo '<ul id="edd_all_access_included_price_ids">';

				for ( $price_id = 1; $price_id <= $number_of_price_ids; $price_id++ ) {

					$variation_string = __( 'th Price Variation from each product', 'edd-all-access' );
					$variation_string = $price_id == 1 ? __( 'st Price Variation from each product', 'edd-all-access' ) : $variation_string;
					$variation_string = $price_id == 2 ? __( 'nd Price Variation from each product', 'edd-all-access' ) : $variation_string;
					$variation_string = $price_id == 3 ? __( 'rd Price Variation from each product', 'edd-all-access' ) : $variation_string;

					echo '<li class="edd_all_access_included_price_id_li ' . $price_id . '" style="display:none;"><input type="checkbox" name="edd_all_access_meta[included_price_ids][]" class="edd_all_access_included_price_id" value="' . esc_attr( $price_id ) . '" ' . esc_attr( ( in_array( $price_id, $included_price_ids ) ? ' checked ' : '' ) ) . '/>' . $price_id . $variation_string . ' &nbsp;</li>';
				}

			echo '</ul>';

		echo '<td>';
	echo '</tr>';

	//All Access Receipt options:
	echo '<tr ' . $display . ' class="edd_all_access_row">';
		echo '<td class="edd_field_type_text" colspan="2">';
			echo '<p><strong>' . __( 'Receipts: Show link to All Access?:', 'edd-all-access' ) . '</strong></p>';
			echo '<label for="edd_all_access_receipt_meta_show_link">' . __( 'Would you like to output a custom link in the receipts your customers receive directing them to use their All Access Pass? Note: For email Receipts, you must be using the', 'edd-all-access' ) . ' <a href="http://docs.easydigitaldownloads.com/article/864-email-settings" target="_blank">{download_list}</a> ' . __( 'email tag.', 'edd-all-access' ) . '</label><br />';

			echo '<select name="edd_all_access_receipt_meta[show_link]" id="edd_all_access_receipt_meta_show_link">';
				echo '<option value="show_link" ' . esc_attr( selected( 'show_link', $show_all_access_link_in_receipt, false ) ) . '>' . __( 'Show link in receipt', 'edd-all-access' ) . '</option>';
				echo '<option value="hide_link" ' . esc_attr( selected( 'hide_link', $show_all_access_link_in_receipt, false ) ) . '>' . __( 'Hide link in receipt', 'edd-all-access' ) . '</option>';
			echo '</select>';

		echo '<td>';
	echo '</tr>';

	//All Access Receipt Link Message:
	echo '<tr ' . $display . ' class="edd_all_access_row">';
		echo '<td class="edd_field_type_text" colspan="2">';
			echo '<p><strong>' . __( 'Receipts: All Access Link Message:', 'edd-all-access' ) . '</strong></p>';
			echo '<label for="edd_all_access_receipt_meta_link_message">' . __( 'What should the link in the receipt say to the user?', 'edd-all-access' ) . '</label>';

			echo '<p><textarea name="edd_all_access_receipt_meta[link_message]" id="edd_all_access_receipt_meta_link_message" style="width:100%;">' . $all_access_link_in_receipt_message . '</textarea></p>';

		echo '<td>';
	echo '</tr>';

	//All Access Receipt Link URL:
	echo '<tr ' . $display . ' class="edd_all_access_row">';
		echo '<td class="edd_field_type_text" colspan="2">';
			echo '<p><strong>' . __( 'Receipts: Link URL:', 'edd-all-access' ) . '</strong></p>';
			echo '<label for="edd_all_access_receipt_meta_link_url">' . __( 'Which URL should the customer be directed to in the receipt? If you want to build your own custom page, ', 'edd-all-access' ) . '<a href="http://docs.easydigitaldownloads.com/article/1829-all-access-creating-all-access-products#creating-a-custom-page-of-products-the-customer-can-download-via-all-access" target="_blank">' . __( 'learn how in this document.', 'edd-all-access' ) . '</a></label>';

			echo '<p><input style="width:100%;" type="url" name="edd_all_access_receipt_meta[link_url]" id="edd_all_access_receipt_meta_link_url" value="' . $all_access_link_in_receipt_url . '" /></p>';

		echo '<td>';
	echo '</tr>';

	echo '</table>';
}

/**
 * Save data from the All Access metabox
 *
 * @access      public
 * @since       1.0.0
 * @param       string $post_id The ID of the post being saved.
 * @return      void
 */
function edd_all_access_download_meta_box_save( $post_id ) {
	global $post;

	// verify nonce
	if ( ! isset( $_POST['edd_download_all_access_meta_box_nonce'] ) || ! wp_verify_nonce( $_POST['edd_download_all_access_meta_box_nonce'], basename( __FILE__ ) ) ) {
		return $post_id;
	}

	// Check for auto save / bulk edit
	if ( ( defined('DOING_AUTOSAVE') && DOING_AUTOSAVE ) || ( defined( 'DOING_AJAX') && DOING_AJAX ) || isset( $_REQUEST['bulk_edit'] ) ) {
		return $post_id;
	}

	if ( isset( $_POST['post_type'] ) && 'download' != $_POST['post_type'] ) {
		return $post_id;
	}

	if ( ! current_user_can( 'edit_product', $post_id ) ) {
		return $post_id;
	}

	if ( false !== wp_is_post_revision( $post_id ) ){
        return;
	}

	if ( isset( $_POST['edd_all_access_enabled'] ) ) {

		update_post_meta( $post_id, '_edd_all_access_enabled', true );

		// Also add this post to the list of All Access posts saved into the options table
		$edd_all_access_products = get_option( 'edd_all_access_products' );
		if ( ! is_array( $edd_all_access_products ) ){
			$edd_all_access_products = array();
		}

		array_push( $edd_all_access_products, $post_id );
		update_option( 'edd_all_access_products', array_unique( $edd_all_access_products ) );

		$new_all_access_meta  = isset( $_POST['edd_all_access_meta'] ) ? $_POST['edd_all_access_meta'] : false;

		if ( $new_all_access_meta ) {

			$sanitized_values = array();

			//Sanitize Values
			foreach( $_POST['edd_all_access_meta'] as $meta_key => $meta_value ){

				switch( $meta_key ){
					case 'all_access_duration_number':
						if ( is_numeric( $meta_value ) ){
							$sanitized_values['all_access_duration_number'] = $meta_value;
						}

						break;
					case 'all_access_duration_unit':
						$sanitized_values['all_access_duration_unit'] = sanitize_text_field( $meta_value );

						break;
					case 'download_limit':
						if ( is_numeric( $meta_value ) ){
							$sanitized_values['all_access_download_limit'] = $meta_value;
						}

						break;
					case 'download_limit_time_period':
						$sanitized_values['all_access_download_limit_time_period'] = sanitize_text_field( $meta_value );

						break;
					case 'all_access_categories':
						$all_access_categories = array();

						foreach( $meta_value as $all_access_category ){
							if( is_numeric( $all_access_category ) ||  $all_access_category == 'all' ){
								$all_access_categories[] = $all_access_category;
							}
						}

						$sanitized_values['all_access_categories'] = $all_access_categories;

						break;
					case 'number_of_price_ids':
						if ( is_numeric( $meta_value ) ){
							$sanitized_values['all_access_number_of_price_ids'] = $meta_value;
						}

						break;
					case 'included_price_ids':

						$included_price_ids = array();

						foreach( $meta_value as $included_price_id ){
							if( is_numeric( $included_price_id ) ){
								$included_price_ids[] = $included_price_id;
							}
						}

						$sanitized_values['all_access_included_price_ids'] = $included_price_ids;

						break;
				}

			}

			update_post_meta( $post_id, '_edd_all_access_settings', $sanitized_values );
		}

		// Check the receipt data as well
		$new_all_access_receipt_meta  = isset( $_POST['edd_all_access_receipt_meta'] ) ? $_POST['edd_all_access_receipt_meta'] : false;

		if ( $new_all_access_receipt_meta ) {

			$sanitized_values = array();

			//Sanitize Values
			foreach( $_POST['edd_all_access_receipt_meta'] as $meta_key => $meta_value ){

				switch( $meta_key ){
					case 'show_link':
						$sanitized_values['show_link'] = sanitize_text_field( $meta_value );

						break;
					case 'link_message':
						$sanitized_values['link_message'] = sanitize_text_field( $meta_value );

						break;
					case 'link_url':
						$sanitized_values['link_url'] = esc_url( $meta_value );

						break;
				}

			}

			update_post_meta( $post_id, '_edd_all_access_receipt_settings', $sanitized_values );
		}

	} else {
		delete_post_meta( $post_id, '_edd_all_access_enabled' );

		// Also remove this post from the list of All Access posts saved into the options table
		$edd_all_access_products = get_option( 'edd_all_access_products' );
		unset( $edd_all_access_products[$post_id] );
		update_option( 'edd_all_access_products', $edd_all_access_products );
	}
}
add_action( 'save_post', 'edd_all_access_download_meta_box_save' );
