<?php
/**
 * Functions that deal with options this plugin adds to the "Prices" metabox for EDD.
 *
 * @package     EDD\EDDAllAccess\Post Meta Functions
 * @since       1.0.0
 */


// Exit if accessed directly
if( !defined( 'ABSPATH' ) ){
	exit;
}

/**
 * Option to exclude this product from All Access
 *
 * @access      public
 * @since       1.0.0
 * @return      void
 */
function edd_all_access_excluded_product( $post_id ) {

	$all_access_exclude = get_post_meta( $post_id, '_edd_all_access_exclude', true ) ? true : false;

	?>
	<p id="edd_all_access_exclude_single_option">
		<label for="edd_all_access_exclude">
			<input type="checkbox" name="_edd_all_access_exclude" id="edd_all_access_exclude" value="1" <?php checked( 1, $all_access_exclude ); ?> />
			<?php echo apply_filters( 'edd_all_access_exclude_toggle_text', __( 'Exclude this product from any All Access passes.', 'edd-all-access' ) );

			// Use nonce for verification
			echo '<input type="hidden" name="edd_all_access_price_meta_box_nonce" value="', wp_create_nonce( basename( __FILE__ ) ), '" />'; ?>

		</label>
	</p>
	<?php
}
add_action( 'edd_after_price_field', 'edd_all_access_excluded_product' );

/**
 * Save All Access data from the prices metabox
 *
 * @access      public
 * @since       1.0.0
 * @param       string $post_id The ID of the post being saved.
 * @return      void
 */
function edd_all_access_price_meta_box_save( $post_id ) {

	// verify nonce
	if ( ! isset( $_POST['edd_all_access_price_meta_box_nonce'] ) || ! wp_verify_nonce( $_POST['edd_all_access_price_meta_box_nonce'], basename( __FILE__ ) ) ) {
		return $post_id;
	}

	// Check for auto save / bulk edit
	if ( ( defined('DOING_AUTOSAVE') && DOING_AUTOSAVE ) || ( defined( 'DOING_AJAX') && DOING_AJAX ) || isset( $_REQUEST['bulk_edit'] ) ) {
		return $post_id;
	}

	if ( ! isset( $_POST['post_type'] ) ||  ( isset( $_POST['post_type'] ) && 'download' != $_POST['post_type'] ) ) {
		return $post_id;
	}

	if ( ! current_user_can( 'edit_product', $post_id ) ) {
		return $post_id;
	}

	if ( isset( $_POST['_edd_all_access_exclude'] ) ) {
		update_post_meta( $post_id, '_edd_all_access_exclude', true );
	} else {
		delete_post_meta( $post_id, '_edd_all_access_exclude' );
	}
}
add_action( 'save_post', 'edd_all_access_price_meta_box_save' );

/**
 * Add "Exclude from All Access" to the variable pricing options
 *
 * @access      public
 * @since       1.0.4
 * @param       int   $download_id
 * @param       int   $price_id
 * @param       array $args
 * @return      void
 */
function edd_all_access_exclude_price_id_option( $download_id, $price_id, $args ) {

	$prices = edd_get_variable_prices( $download_id );

 	if ( ! empty( $prices[ $price_id ][ 'excluded_price' ] ) ) {
 		$price_excluded = true;
 	}
 	else{
 		$price_excluded = false;
 	}

	?>
	<div class="edd-custom-price-option-section">
		<span class="edd-custom-price-option-section-title"><?php _e( 'All Access Settings', 'edd-all-access' ); ?></span>
		<div class="edd-custom-price-option-section-content">
			<span><?php _e( 'Exclude from All Access?', 'edd-all-access' ); ?></span><span alt="f223" class="edd-help-tip dashicons dashicons-editor-help" title="<?php _e( '<strong>Exclude from All Access</strong>: Check this setting to exclude this price from every All Access pass. If checked, no one with any All Access pass will be able to download this price\'s files using All Access.', 'edd-all-access' ); ?>"></span>
			<input <?php checked( true, $price_excluded, true ); ?> type="checkbox" name="edd_variable_prices[<?php echo $price_id; ?>][excluded_price]" id="edd_variable_prices[<?php echo $price_id; ?>][excluded_price]" value="1" />
		</div>
	</div>
	<?php
}
add_action( 'edd_download_price_table_row', 'edd_all_access_exclude_price_id_option', 10, 3 );
