<?php
/**
 * Scripts
 *
 * @package     EDD\PluginName\Scripts
 * @since       1.0.0
 */


// Exit if accessed directly
if( !defined( 'ABSPATH' ) ) exit;


/**
 * Load admin scripts
 *
 * @since       1.0.0
 * @global      array $edd_settings_page The slug for the EDD settings page
 * @global      string $post_type The type of post that we are editing
 * @return      void
 */
function edd_all_access_admin_post_meta_scripts( $hook ) {

	global $pagenow;

	// Check if the page vriable exists in the url
	$page_url_variable = isset( $_GET['page'] ) ? sanitize_title( $_GET['page'] ) : NULL;

	// If current page is not one where we need custom styles/scripts
	if ( 'post.php' !== $pagenow && 'post-new.php' !== $pagenow && 'edd-all-access-pass' !== $page_url_variable  ){
		//return false;
	}

	// Use minified libraries if SCRIPT_DEBUG is turned off
	$suffix = ( defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ) ? '' : '.min';

	wp_enqueue_script( 'edd_all_access_admin_js', EDD_ALL_ACCESS_URL . 'assets/js/admin-eddaa' . $suffix . '.js', array( 'jquery' ) );
	wp_localize_script( 'edd_all_access_admin_js', 'edd_all_access_vars',
		array(
			'first_variation_string' => __( 'st Price Variation from each product', 'edd-all-access' ),
			'second_variation_string' => __( 'nd Price Variation from each product', 'edd-all-access' ),
			'third_variation_string' => __( 'rd Price Variation from each product', 'edd-all-access' ),
			'variation_string' => __( 'th Price Variation from each product', 'edd-all-access' ),
			'manage_all_access_expire_warning' => __( 'NOTICE: This will make this All Access Pass expire. This can not be undone. In order to re-activate, the customer must re-purchase. Are you sure you want to do this?', 'edd-all-access' )
		)
	);

	//wp_enqueue_style( 'edd_all_access_admin_css', EDD_ALL_ACCESS_URL . '/assets/css/admin' . $suffix . '.css' );

}
add_action( 'admin_enqueue_scripts', 'edd_all_access_admin_post_meta_scripts', 100 );


/**
 * Load frontend scripts
 *
 * @since       1.0.0
 * @return      void
 */
function edd_all_access_scripts( $hook ) {

	// Use minified libraries if SCRIPT_DEBUG is turned off
	$suffix = ( defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ) ? '' : '.min';

	wp_enqueue_style( 'edd_all_access_css', EDD_ALL_ACCESS_URL . 'assets/css/styles' . $suffix . '.css' );

	// Only enqueue All Access scripts if the user is logged in
	if ( ! is_user_logged_in() ){
		return false;
	}

	wp_enqueue_script( 'edd_all_access_js', EDD_ALL_ACCESS_URL . 'assets/js/eddaa-scripts' . $suffix . '.js', array( 'jquery' ) );
	wp_localize_script( 'edd_all_access_js', 'edd_all_access_vars',
		array(
			'ajaxurl' => admin_url( 'admin-ajax.php' ),
			'ajax_nonce_value' => wp_create_nonce( 'edd-all-access-nonce-action-name' ),
			'loading_text' => __( 'Loading', 'edd-all-access' ),
		)
	);

}
add_action( 'wp_enqueue_scripts', 'edd_all_access_scripts' );
