<?php
/**
 * Integration functions to make All Access compatible with the EDD Free Downloads extension
 *
 * All Access and Free Downloads work together like this:
 * If the user is logged out and a price is free, they will get the normal "Free Downloads" dialog when trying to download/purchase.
 * If the user is logged in, a price is free, and they DO NOT have All Access permission to download the item,
 * they will get the normal "Free Downloads" dialog when trying to download/purchase.
 * If the user is logged in, a price is free, and they DO have All Access permission to download the item, they will download it using the All Access download URL and it will be logged
 * using the All Access payment as the payment used to download the item. At this time, no special functions are needed to make this work.
 * If you wish to "force" a free download to always use the "Free Downloads" dialog/system, edit the product in question and check the box called "Exclude from All Access?" for that price.
 *
 * @package     EDD\EDDAllAccess\Functions
 * @since       1.0.0
 */

// Exit if accessed directly
if( !defined( 'ABSPATH' ) ) exit;

/**
 * Integrates EDD All Access with the EDD Free Downloads extension
 *
 * @since 1.0.0
 */
class EDD_All_Access_Free_Downloads {

	/**
	 * Get things started
	 *
	 * @since  1.0.0
	 * @return void
	 */
	public function __construct() {

		if ( ! class_exists( 'EDD_Free_Downloads' ) ) {
			return;
		}

		add_filter( 'edd_all_access_enqueue_jbox', array( $this, 'prevent_jbox_enqueue' ) );

		add_filter( 'edd_all_access_required_before_modal', array( $this, 'required_scripts_for_jbox' ) );
	}

	/**
	 * EDD All Access uses the same modal popup library as Free Downloads for 1 specific shortcode [edd_aa_login_and_purchase].
	 * To prevent loading it twice, we tell EDD All Access not to load it if Free Downloads is active.
	 *
	 * @since       1.0.0
	 */
	public function prevent_jbox_enqueue(){
		return false;
	}

	/**
	 * EDD All Access uses the same modal popup library as Free Downloads for 1 specific shortcode [edd_aa_login_and_purchase].
	 * To prevent loading it twice, we tell EDD All Access not to load it if Free Downloads is active.
	 *
	 * @since       1.0.0
	 */
	public function required_scripts_for_jbox( $required_scripts ){

		// Remove the requirement for the jbox script from All Access because we can rely on the Free Downloads one instead.
		if(($key = array_search('edd-all-access-jbox', $required_scripts)) !== false) {
		    unset($required_scripts[$key]);
		}

		// Add the requirement for the Free Downloads jbox
		$required_scripts[] = 'edd-free-downloads-modal';

		return $required_scripts;
	}

}
